@@ -226,3 +226,17 @@ class CoordinateSystem(dj.Imported):
         key_coord['coordinate_system_name'] = grf(key, 'name')
         key_coord['coordinate_system_description'] = grf(key, 'description')
         self.insert1(key_coord)
+
+
+@schema
+class BrainRegion(dj.Lookup):
+    definition = """
+    brain_region_pk     : int               # primary key of brain region consistent with Allen marking
+    ---
+    acronym             : varchar(32)       # e.g. "Su3",
+    brain_region_name   : varchar(128)      # fullname of the brain region
+    parent=null         : int               # pk of the parent
+    ontology='CCF 2017' : varchar(32)       # ccf version
+    brain_region_level=null          : tinyint           # level in the tree, root is 0
+    graph_order=null    : smallint unsigned # graph order shown in allen brain atlas
+    """
